@@ -1,10 +1,11 @@
 use strictures 1;
 package Chart::Weather::Forecast::Temperature;
 BEGIN {
-  $Chart::Weather::Forecast::Temperature::VERSION = '0.03';
+  $Chart::Weather::Forecast::Temperature::VERSION = '0.04';
 }
 use Moose;
 use namespace::autoclean;
+use MooseX::Types::Path::Class;
 
 use Chart::Clicker;
 use Chart::Clicker::Data::Range;
@@ -95,9 +96,11 @@ has 'lows' => (
     required => 1,
 );
 has 'chart_temperature_file' => (
-    is      => 'ro',
-    isa     => 'Path::Class::File',
-    default => sub {  Path::Class::File->new(File::Spec->tmpdir, 'temperature-forecast.png') },
+    is        => 'ro',
+    isa       => 'Path::Class::File',
+    required  => 1,
+    coerce    => 1,
+    'default' => sub {  Path::Class::File->new(File::Spec->tmpdir, 'temperature-forecast.png') },
 );
 has 'chart_format' => (
     is      => 'ro',
